"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const command_1 = require("@oclif/command");
const docker_command_1 = tslib_1.__importDefault(require("../../docker-command"));
const version_1 = tslib_1.__importDefault(require("../../version"));
const status_1 = tslib_1.__importDefault(require("./status"));
class Start extends docker_command_1.default {
    async run() {
        const { flags } = this.parse(Start);
        const status = await status_1.default.run(['--name', flags.name, '--silent']);
        if (status === 0 /* STARTED */) {
            this.log('Engine is already started');
            return false;
        }
        this.spinner.start('Starting Engine');
        const eventPromise = this.waitForEvent(({ Action, Type, from }) => Type === 'container' &&
            Action === 'start' &&
            from === `mesg/engine:${flags.version}`);
        const network = await this.getOrCreateNetwork({ name: flags.name });
        await this.createService(network, {
            name: flags.name,
            version: flags.version,
            colors: flags['log-force-colors'],
            format: flags['log-format'],
            level: flags['log-level']
        });
        await eventPromise;
        this.spinner.stop();
        return true;
    }
}
Start.description = 'Start the Engine';
Start.flags = Object.assign({}, docker_command_1.default.flags, { version: command_1.flags.string({
        description: 'Version of the Engine to run',
        required: true,
        default: version_1.default.engine
    }), 'log-force-colors': command_1.flags.boolean({
        description: 'Log force colors',
        default: false
    }), 'log-format': command_1.flags.enum({
        description: 'Log format',
        default: 'text',
        options: ['text', 'json']
    }), 'log-level': command_1.flags.enum({
        description: 'Log level',
        default: 'info',
        options: ['debug', 'info', 'warn', 'error', 'fatal', 'panic']
    }) });
exports.default = Start;
