"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const cli_ux_1 = require("cli-ux");
const fs_1 = require("fs");
const path_1 = require("path");
const marketplace_command_1 = tslib_1.__importDefault(require("../../marketplace-command"));
const compile_1 = tslib_1.__importDefault(require("../service/compile"));
const create_1 = tslib_1.__importDefault(require("../service/create"));
const detail_1 = tslib_1.__importDefault(require("../service/detail"));
class MarketplacePublish extends marketplace_command_1.default {
    async run() {
        const { args } = this.parse(MarketplacePublish);
        const path = args.SERVICE_PATH;
        const account = await this.getAccount();
        this.spinner.start('Preparing service');
        const compiledService = await compile_1.default.run([path, '--silent']);
        const createResponse = await create_1.default.run([JSON.stringify(compiledService), '--silent']);
        const definition = await detail_1.default.run([createResponse.hash, '--silent']);
        const serviceTx = await this.preparePublishService({
            definition,
            readme: this.lookupReadme(path),
            hash: definition.hash,
            hashVersion: '1',
            deployment: {
                type: 'ipfs',
                source: definition.source
            }
        }, account);
        this.spinner.stop();
        if (!await cli_ux_1.cli.confirm(`Do you confirm to send a transaction to ${serviceTx.to} with the account ${account}?`)) {
            return null;
        }
        const passphrase = await this.getPassphrase();
        this.spinner.start('Publishing service');
        const marketplaceService = await this.publishService(account, serviceTx, passphrase);
        this.spinner.stop();
        this.styledJSON(marketplaceService);
        return marketplaceService;
    }
    async preparePublishService(service, account) {
        return this.execute({
            instanceHash: await this.engineServiceInstance(marketplace_command_1.default.SERVICE_NAME),
            taskKey: 'preparePublishServiceVersion',
            inputs: JSON.stringify({
                service,
                from: account
            })
        });
    }
    async publishService(account, serviceTx, passphrase) {
        const signedTx = await this.sign(account, serviceTx, passphrase);
        return this.execute({
            instanceHash: await this.engineServiceInstance(marketplace_command_1.default.SERVICE_NAME),
            taskKey: 'publishPublishServiceVersion',
            inputs: JSON.stringify(signedTx)
        });
    }
    lookupReadme(path) {
        const readmeRegexp = /^readme(.md)?$/i;
        const readme = fs_1.readdirSync(path).find(x => !!x.match(readmeRegexp));
        if (!readme) {
            return '';
        }
        return fs_1.readFileSync(path_1.join(path, readme)).toString();
    }
}
MarketplacePublish.description = 'Publish a service';
MarketplacePublish.flags = Object.assign({}, marketplace_command_1.default.flags);
MarketplacePublish.args = [{
        name: 'SERVICE_PATH',
        description: 'Path of the service',
        required: true,
        default: './'
    }];
exports.default = MarketplacePublish;
