"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const root_command_1 = tslib_1.__importDefault(require("../../root-command"));
const compile_1 = tslib_1.__importDefault(require("./compile"));
const create_1 = tslib_1.__importDefault(require("./create"));
const delete_1 = tslib_1.__importDefault(require("./delete"));
const logs_1 = tslib_1.__importDefault(require("./logs"));
const start_1 = tslib_1.__importDefault(require("./start"));
const stop_1 = tslib_1.__importDefault(require("./stop"));
class ServiceDev extends root_command_1.default {
    async run() {
        const { args, flags } = this.parse(ServiceDev);
        const definition = await compile_1.default.run([args.SERVICE, '--silent']);
        const service = await create_1.default.run([JSON.stringify(definition)]);
        const envs = (flags.env || []).reduce((prev, value) => [...prev, '--env', value], []);
        const instance = await start_1.default.run([service.hash, ...envs]);
        const stream = await logs_1.default.run([instance.hash]);
        process.once('SIGINT', async () => {
            stream.destroy();
            await stop_1.default.run([instance.hash]);
            await delete_1.default.run([service.hash, '--confirm']);
        });
    }
}
ServiceDev.description = 'Run a service in development mode';
ServiceDev.flags = Object.assign({}, root_command_1.default.flags, create_1.default.flags, start_1.default.flags);
ServiceDev.args = [{
        name: 'SERVICE',
        description: 'Path or url ([https|mesg]://) of a service',
        default: './'
    }];
exports.default = ServiceDev;
