"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const command_1 = require("@oclif/command");
const cli_ux_1 = require("cli-ux");
const inquirer_1 = require("inquirer");
const account_command_1 = require("./account-command");
const root_command_1 = tslib_1.__importDefault(require("./root-command"));
class MarketplaceCommand extends root_command_1.default {
    async sign(account, data, passphrase) {
        return this.execute({
            instanceHash: await this.engineServiceInstance(account_command_1.WithoutPassphrase.SERVICE_NAME),
            taskKey: 'sign',
            inputs: JSON.stringify({
                passphrase,
                address: account,
                transaction: data,
            })
        });
    }
    async getAccount() {
        const { flags } = this.parse();
        if (flags.account) {
            return flags.account;
        }
        const { addresses } = await this.execute({
            instanceHash: await this.engineServiceInstance(account_command_1.WithoutPassphrase.SERVICE_NAME),
            taskKey: 'list',
            inputs: JSON.stringify({})
        });
        if (!addresses.length) {
            throw new Error('You need to create an account first.');
        }
        if (addresses.length === 1) {
            return addresses[0];
        }
        const { account } = (await inquirer_1.prompt({
            type: 'list',
            name: 'account',
            message: 'Select the account to use:',
            choices: addresses
        }));
        return account;
    }
    async getPassphrase() {
        const { flags } = this.parse();
        if (flags.passphrase) {
            return flags.passphrase;
        }
        return cli_ux_1.cli.prompt('Type the passphrase', { type: 'hide' });
    }
}
MarketplaceCommand.flags = Object.assign({}, root_command_1.default.flags, { account: command_1.flags.string({
        char: 'a',
        description: 'Account to use'
    }), passphrase: command_1.flags.string({
        char: 'p',
        description: 'Passphrase to unlock the account'
    }) });
MarketplaceCommand.SERVICE_NAME = 'Marketplace';
exports.default = MarketplaceCommand;
