"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const fs_1 = require("fs");
const hosted_git_info_1 = require("hosted-git-info");
const ignore_1 = tslib_1.__importDefault(require("ignore"));
const is_git_url_1 = tslib_1.__importDefault(require("is-git-url"));
const os_1 = require("os");
const path_1 = require("path");
const rimraf_1 = require("rimraf");
const tar_1 = tslib_1.__importDefault(require("tar"));
const uuid_1 = require("uuid");
const validator_1 = require("validator");
const downloadTarball = require('download-tarball');
const gitclone = require('git-clone');
const downloadSrc = async (url) => {
    const dir = path_1.join(os_1.tmpdir(), uuid_1.v4());
    if (hosted_git_info_1.fromUrl(url)) {
        return clone(url, dir);
    }
    await downloadTarball({ url, dir });
    return dir;
};
const clone = async (git, dir) => {
    const url = git.split('#')[0];
    const checkout = git.split('#')[1] || 'master';
    return new Promise((resolve, reject) => {
        const opts = {
            checkout,
            shallow: checkout === 'master'
        };
        gitclone(url, dir, opts, (err) => {
            if (err)
                return reject(err);
            rimraf_1.sync(path_1.join(dir, '.git'));
            return resolve(dir);
        });
    });
};
const preprocessPath = (path) => {
    const directories = fs_1.readdirSync(path)
        .map(name => path_1.join(path, name))
        .filter(x => fs_1.lstatSync(x).isDirectory());
    if (fs_1.readdirSync(path).length === 1 && directories.length === 1) {
        return directories[0];
    }
    return path;
};
exports.createTar = (path) => {
    const mesgignore = path_1.join(path, '.mesgignore');
    const ig = ignore_1.default().add([
        '.git',
        ...(fs_1.existsSync(mesgignore) ? fs_1.readFileSync(mesgignore).toString().split('\n') : [])
    ]);
    return tar_1.default.create({
        cwd: path,
        filter: ig.createFilter(),
        strict: true,
        gzip: true,
        portable: true,
    }, fs_1.readdirSync(path))
        .on('error', (error) => {
        throw error;
    });
};
exports.default = async (pathOrUrl) => {
    if (is_git_url_1.default(pathOrUrl) || validator_1.isURL(pathOrUrl)) {
        return preprocessPath(await downloadSrc(pathOrUrl));
    }
    return preprocessPath(pathOrUrl);
};
